<?php
/**
* Avoid direct call of the file
*/
if (!function_exists('add_action')) {
    header('Status: 403 Forbidden');
    header('HTTP/1.1 403 Forbidden');
    exit();
}

if (!class_exists('BLN_HELPER')) {
    class BLN_HELPER
    {
        /**
        * The theme options.
        */
        private $options = null;
        
        /**
        * Constructor of the helper class
        */
        public function __construct()
        {
            $this->load_db();
        }
        
        /**
        * Load theme options
        *
        * @since 1.0
        */
        public function load_db()
        {
            $options = get_option(BLN_OPTION_NAME);
            if (!isset($options['version'])) {
                global $bln_default_options;
                $this->options = $bln_default_options;
                update_option(BLN_OPTION_NAME, $bln_default_options);
            } else {
                $this->options = $options;
            }
        }
        
        /**
        * Get theme options
        */
        public function get_theme_options()
        {
            return $this->options;
        }
        
        /**
        * Get all font stacks
        *
        * @since 1.0
        * @return array $stacks, all font stacks
        */
        public function get_font_stacks()
        {
            $stacks = array(
                'Arial' => 'Arial, "Helvetica Neue", Helvetica, sans-serif',
                'Baskerville' => 'Baskerville, "Times New Roman", Times, serif',
                'Georgia' => 'Georgia, Times, "Times New Roman", serif',
                'Helvetica' => '"Helvetica Neue", Helvetica, Arial, sans-serif',
                'Lucida' => '"Lucida Sans", Lucida Grande", "Lucida Sans Unicode", sans-serif',
                'Monaco' => 'Monaco, Menlo, Consolas, "Courier New", monospace, serif',
                'Palatino' => 'Palatino, "Palatino Linotype", Georgia, Times, "Times New Roman", serif',
                'Tahoma' => 'Tahoma, Geneva, Verdana, sans-serif',
                'Times' => '"Times New Roman", Times, serif',
                'Trebuchet' => '"Trebuchet MS", "Lucida Sans Unicode", "Lucida Grande", "Lucida Sans", sans-serif',
                'Verdana' => 'Verdana, Geneva, Tahoma, sans-serif',
            );
            return apply_filters('bln_font_stacks', $stacks);
        }
        
        /**
        * Display script and styles in the <head /> section.
        */
        public function wp_head()
        {
            $fonts = $this->get_font_stacks();
            $color = get_header_textcolor();
            ?>
            <style type="text/css">
                body {font-family: <?php echo $fonts[$this->options['font']['body']]; ?>;}
                code, pre {font-family: <?php echo $fonts[$this->options['font']['code']]; ?>;}
                input, button, select, textarea {font-family: <?php echo $fonts[$this->options['font']['inputs']]; ?>;}
                #site-title a {color: #<?php echo $color; ?>;}
                #site-description {text-decoration: none; color: #<?php echo $color; ?>;}<?php
                if (get_header_image()) {
                ?>
                #site-head {height: 275px; background: url("<?php header_image(); ?>") scroll top; background-size: cover;}
                <?php
                }
                if (has_nav_menu('top')) {?>
                #site-header { margin-top: -10px;}
                <?php
                }
                ?>
            </style>
            <?php
            if (is_front_page() && array() != $this->options['slider']['slides']) {
            ?>
                <script type="text/javascript">
                    /* <![CDATA[ */
                    var bln_slider = <?php echo json_encode($this->options['slider'], JSON_FORCE_OBJECT); ?>;
                    /* ]]> */
                </script>
            <?php
            }
        }
        
        /**
        * Display the sidebar's class
        */
        public function sidebar_class()
        {
            $pos = $this->options['sidebar'];
            if (is_active_sidebar('sidebar1')) {
                $output = ('left' == $pos) ? 'span3 offset1' : 'span3';
                echo $output;
            }
        }
        
        /**
        * Display main content's class
        */
        public function main_content_class()
        {
           $pos = $this->options['sidebar'];
            if (!is_active_sidebar('sidebar1')) {
                echo "span10 offset1";
            } elseif ('left' == $pos) {
                echo "span7";
            } else {
                echo "span7 offset1";
            }
        }
        
        /**
        * Check if a post is displayable regarding post status and user login status
        *
        * @since 1.0
        * @param int $id, the post'ID
        */
        public function is_displayable($id)
        {
            $status = get_post_status($id);
            if ('publish' == $status || ('private' == $status && is_user_logged_in())) {
                return true;
            } else {
                return false;
            }
        }
        
        /**
        * Display the search form in nav bar
        */
        public function navbar_searchform()
        {
            if(!$this->options['navbar_search']) return;
            ?>
            <form method="get" id="searchform" class="navbar-form pull-right" action="<?php echo esc_url(home_url('/')); ?>">
                <input type="text" name="s" id="s" placeholder="Search" value="<?php echo esc_attr(get_search_query()); ?>" />
                <input type="submit" class="btn" name="submit" id="searchsubmit" value="Search" />
            </form>
            <?php
        }
        
        /**
        * Display meta info on post/page
        */
        public function post_meta()
        {
            $cat = get_the_category_list('&nbsp;');
            $cat = str_replace('<a ', '<a class="btn btn-small" ', $cat);
            $tag = get_the_tag_list('', ' ');
            $tag = str_replace('<a ', '<a class="btn btn-inverse btn-small"', $tag);
            $aut_url = get_author_posts_url(get_the_author_meta('ID'));
            $aut = get_the_author();
            $date = get_the_date();
            $meta;
            if ('page' != get_post_type(get_the_id())) {
                $meta = sprintf(__('Posted by %1$s on %2$s', 'bluelines'), 
                    sprintf('<a href="%1$s" title="%2$s">%3$s</a>', esc_url($aut_url), esc_attr(sprintf(__('View all post by %s', 'bluelines'), $aut)), $aut),
                    '<a href="' . esc_url(get_permalink()) . '">' . $date . '</a>'
                );
            } else {
                $meta = sprintf(__('By %s', 'bluelines'), 
                    sprintf('<a href="%1$s" title="%2$s">%3$s</a>', esc_url($aut_url), esc_attr(sprintf(__('View all post by %s', 'bluelines'), $aut)), $aut));
            }
            if (!empty($cat) || !empty($tag) && 'page' != get_post_type(get_the_id())) {
                $meta .= ', ';
                if (!empty($cat)) $meta .= ' ' . __('in ', 'bluelines') . $cat;
                if (!empty($tag)) $meta .= ' ' . __('tagged ', 'bluelines') . $tag;
            }
            echo '<div class="well well-small muted">' . apply_filters('bln_post_meta', $meta) . '</div><!-- .well -->';
        }
        
        /**
        * For paginated post/page
        */
        public function post_pagination() {
            $type = (is_singular()) ? '' : ' pagination-mini';
            $link_pages_arg = array(
                'before' => '<div class="pagination' . $type . '"><ul><li class="disabled"><span><strong>' . __('Pages: ', 'bluelines') . '</strong></span></li>',
                'after' => '</ul></div>',
                'link_before' => 'l lim',
                'link_after' => 'r lim',
                'next_or_number' => 'number',
            );
            ob_start();
            wp_link_pages($link_pages_arg);
            $output = ob_get_clean();
            $output = str_replace(array(' l lim', 'r lim ', 'r lim', 'l lim', '<a ', '/a>'), array('<li class="disabled"><span>', '</span></li>', '', '', '<li><a ', '/a></li>'), $output);
            echo $output; 
        }
        
        /**
        * Pagination of archives and search result
        */
        public function archives_pagination()
        {
            global $wp_query;
            
            if ($wp_query->max_num_pages > 1) {
                ?>
                <div class="pagination">
                    <ul>
                    <?php
                        $big = 999999;
                        $output = paginate_links(array(
                            'base' => str_replace($big, '%#%', esc_url(get_pagenum_link($big))),
                            'format' => '?paged=%#%',
                            'current' => max(1, get_query_var('paged')),
                            'total' => $wp_query->max_num_pages
                      ));
                        $output =  str_replace(array('<a ', '/a>'), array('<li><a ', '/a></li>'), $output);
                        $output =  str_replace(array('<span ', '/span>'), array('<li class="disabled"><span ', '/span></li>'), $output);
                        echo $output;
                    ?>
                    </ul>
                </div><!-- .pagination --><?php
            }
        }
        
        /**
        * Display the comment reply form
        */
        public function comment_form()
        {
            ob_start();
            comment_form();
            $output = ob_get_clean();
            echo str_replace(' name="submit"', ' name="submit" class="btn btn-success"', $output);
        }
        
        /**
        * Return the appropriate widget class in horizontal widget area (front page and footers)
        *
        * @param string $sidebar, the ID of the sidebar
        */
        public function horizontal_widget_class($sidebar)
        {
            $widgets = wp_get_sidebars_widgets();
            $count = (isset($widgets[$sidebar])) ? count($widgets[$sidebar]) : 0;
            switch ($count) {
                case 1 :
                    return 'span10 offset1';
                    break;
                case 2 :
                    return 'span6';
                    break;
                case 3 :
                    return 'span4';
                    break;
                case 4 :
                    return 'span3';
                    break;
                default :
                    return 'span4';                
            }
        }
        
        /**
        * Display the post thumbnail
        */
        public function post_thumbnail()
        {
            if (has_post_thumbnail()) {
                if (is_singular()) {
                    $id = get_post_thumbnail_id();
                    $url = wp_get_attachment_image_src($id, 'full');
                    if (false !== $url) {
                        $src_size = getimagesize($url[0]);
                        $css = (1.2 < $src_size[1]/$src_size[0]) ? ' pull-right wp-post-image vertical-post-image img-polaroid' : ' aligncenter wp-post-image horizontal-post-image img-polaroid';
                        $max_size = (1.2 < $src_size[1]/$src_size[0]) ? array(200, 600) : 'full';
                        $literal_size = (is_array($max_size)) ? implode('x', $max_size) : 'full';
                        echo wp_get_attachment_image($id, $max_size, false, array('class' => 'attachment-' . $literal_size . $css));
                    }
                } else {
                    if (!is_search()) {
                        echo get_the_post_thumbnail(get_the_id(), 'thumbnail', array('class' => 'alignright wp-post-thumbnail img-rounded'));
                    } else {
                        echo get_the_post_thumbnail(get_the_id(), 'thumbnail', array('class' => 'alignleft wp-post-thumbnail img-rounded'));
                    }
                }
            }
        }
        
        /**
        * Return comment count for the current post/page
        */
        public function comments_count()
        {
            global $post;
            if (empty($post->ID))
                return false;
            $comment_count = wp_count_comments($post->ID);
            return $comment_count->total_comments;
        }
        
        /**
        * The comment callback
        */
        public function comments_cb($comment, $args, $depth)
        {
            $GLOBALS['comment'] = $comment;
            switch ($comment->comment_type) :
                case 'pingback' :
                case 'trackback' :
            ?>
            <li class="post pingback">
                <p class="alert alert-warning"><?php _e('Pingback: ', 'bluelines'); ?>
                    <?php comment_author_link(); ?></span>
                    <?php edit_comment_link(__('Edit this comment', 'bluelines'), '<span class="label label-warning"><i class="icon-edit icon-white"></i>', '</span>'); 
                ?></p>
            <?php
                    break;
                default :
                    ob_start();
                    comment_class();
                    $com_class = ob_get_clean();
            ?>
            <li <?php echo $com_class; ?> id="li-comment-<?php comment_ID(); ?>">
                <article id="comment-<?php comment_ID(); ?>">
                <?php
                    $avatar_size = 64;
                    if ('0' != $comment->comment_parent && false === stripos($com_class, 'depth-1')) {
                        $avatar_size = 32;
                    }
                    ?>
                    <div class="alignleft author-avatar"><?php echo get_avatar($comment, $avatar_size); ?></div><!-- .author-avatar -->
                    <div class="alignright author-info">
                    <?php
                    $byauth = (false === stripos($com_class, 'bypostauthor')) ? '' : '<span class="label label-warning"><i class="icon-user icon-white"></i>' . __('The Author', 'bluelines') . '</span>';
                    printf(__('By %1$s %3$s on %2$s', 'bluelines'),
                        sprintf('<span class="author">%s</span>', get_comment_author_link()),
                        sprintf('<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
                            esc_url(get_comment_link($comment->comment_ID)),
                            get_comment_time('c'),
                            sprintf(__('%1$s at %2$s', 'bluelines'), get_comment_date(), get_comment_time())
                        ),
                        $byauth
                    );
                    ?>
                    </div><!-- .author-info -->
                    <div class="comment-action clearfix">
                        <?php edit_comment_link(__('Edit this comment', 'bluelines'), '<span class="edit-comment-link label label-warning"><i class="icon-edit icon-white"></i>', '</span>'); ?>
                        <?php if ('0' == $comment->comment_approved) : ?>
                            <p class="comment-awaiting-moderation"><?php _e('Your comment is awaiting moderation.', 'bluelines'); ?></p>
                        <?php endif; ?>
                    </div><!-- .comment-action -->
                    <div class="comment-content"><?php comment_text(); ?></div>
                    <div class="reply">
                        <?php comment_reply_link(array_merge($args, array('reply_text' => '<span class="label label-success"><i class="icon-pencil icon-white"></i> ' . __('Reply', 'bluelines') .  '&raquo;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
                    </div><!-- .reply -->
                </article>
                <?php
                    break;
            endswitch;
        }
        
        /**
        * Display the Featured Pages Slider (available only on front page)
        */
        public function slider()
        {
            $slider = $this->options['slider'];
            if (!is_front_page() || array() == $slider['slides']) {
                return;
            }
            $get_post_thumbs = function ($page_id) {
                $img = wp_get_attachment_image_src(get_post_thumbnail_id($page_id), 'full');
                return $img[0];
            };
            $get_post_title = function ($page_id) {
                return esc_attr(get_the_title($page_id));
            };
            $get_post_excerpt = function ($page_id) {
                $page = get_post($page_id);
                $feat_exerpt_length = 55;
                $excerpt = wp_trim_words($page->post_content, apply_filters('bln_slider_excerpt_length', $feat_exerpt_length));
                return esc_attr(strip_shortcodes($excerpt));
            };
            $get_post_links = function ($page_id) {
                return esc_url(get_permalink($page_id));
            };
            $slides = array_map($get_post_thumbs, $slider['slides']);
            $slides_titles = array_map($get_post_title, $slider['slides']);
            $slides_exs = array_map($get_post_excerpt, $slider['slides']);
            $slides_links = array_map($get_post_links, $slider['slides']);
            ?>
            <div id="pages-slider">
                <?php for ($i = 0; $i < count($slides); $i++) : ?>
                    <a class="feat-page" href="<?php echo $slides_links[$i]; ?>" data-cycle-title="<?php echo $slides_titles[$i]; ?>" data-cycle-desc="<?php echo $slides_exs[$i]; ?>">
                        <div class="feat-page-block" style="background: url('<?php echo esc_url($slides[$i]); ?>') no-repeat center center; background-size: cover;">
                        </div>
                    </a><!-- .cycle-slide -->
                <?php endfor; ?>
                <div class="overlay"></div><!-- .overlay -->
            </div><!-- #feat-pages-slider -->
            <?php
        }
    }
}
