<?php
/**
* Avoid direct call of the file
*/
if (!function_exists('add_action')) {
    header('Status: 403 Forbidden');
    header('HTTP/1.1 403 Forbidden');
    exit();
}

if (!class_exists('BLN_MAIN_MENU_WALKER')) {
    class BLN_MAIN_MENU_WALKER extends Walker_Nav_Menu
    {
        function display_element ($element, &$children_elements, $max_depth, $depth = 0, $args, &$output)
        {
            // check, whether there are children for the given ID and append it to the element with a (new) ID
            $element->hasChildren = isset($children_elements[$element->ID]) && !empty($children_elements[$element->ID]);
            return parent::display_element($element, $children_elements, $max_depth, $depth, $args, $output);
        }
        
        /**
        * @param string $output Passed by reference. Used to append additional content.
        * @param int $depth Depth of page. Used for padding.
        */
        function start_lvl(&$output, $depth = 0, $args = array())
        {
            $indent = str_repeat("\t", $depth);
            $output .= "\n$indent<ul class=\"dropdown-menu keepOpen\">\n";
        }

        /**
        * @param string $output Passed by reference. Used to append additional content.
        * @param int $depth Depth of page. Used for padding.
        */
        function end_lvl(&$output, $depth = 0, $args = array())
        {
            $indent = str_repeat("\t", $depth);
            $output .= "$indent</ul>\n";
        }

        /**
        * @param string $output Passed by reference. Used to append additional content.
        * @param object $item Menu item data object.
        * @param int $depth Depth of menu item. Used for padding.
        * @param int $current_page Menu item ID.
        * @param object $args
        */
        function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0)
        {
            $indent = ($depth) ? str_repeat("\t", $depth) : '';

            $class_names = '';

            $classes = empty($item->classes) ? array() : (array) $item->classes;
            $classes[] = 'menu-item-' . $item->ID;
            $active = array_search('current-menu-item', $classes);
            $ancestor = array_search('current-menu-ancestor', $classes);
            if (false !== $active) $classes[$active] = 'active';
            if (false !== $ancestor) $classes[$ancestor] = 'active';
            if ($item->hasChildren && 0 == $depth) $classes[] = 'dropdown';
            
            $class_names = join(' ', $classes);
            $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

            $data_toggle = ($item->hasChildren && 0 == $depth) ? ' data-toggle="dropdown"' : '';
            
            $id = $id ? ' id="' . esc_attr($item->id) . '"' : '';

            $output .= $indent . '<li' . $id . $class_names . $data_toggle . '>';

            $attributes  = !empty($item->attr_title) ? ' title="' . esc_attr($item->attr_title) . '"' : '';
            $attributes .= !empty($item->target) ? ' target="' . esc_attr($item->target) . '"' : '';
            $attributes .= !empty($item->xfn) ? ' rel="' . esc_attr($item->xfn) . '"' : '';
            $attributes .= !empty($item->url) ? ' href="' . esc_attr($item->url) . '" data-target="#"' : '';
            $attributes .= ($item->hasChildren && 0 == $depth) ? ' class="toplevel-item"' : '';
            

            $item_output = $args->before;
            $item_output .= '<a'. $attributes .'>';
            $item_output .= $args->link_before . $item->title . $args->link_after;
            $item_output .= '</a>';
            $item_output .= ($item->hasChildren && 0 == $depth) ? '<a class="dropdown-toggle navbar-caret" data-toggle="dropdown"><b class="caret"></b></a>' : '';
            $item_output .= $args->after;

            $output .= $item_output;
        }

        /**
        * @param string $output Passed by reference. Used to append additional content.
        * @param object $item Page data object. Not used.
        * @param int $depth Depth of page
        */
        function end_el(&$output, $item, $depth = 0, $args = array())
        {
            $output .= "</li>\n";
            if (0 == $depth) $output .= '<li class="divider-vertical"></li>';
        }
    }
}
