<?php
/**
* Avoid direct call of the file
*/
if (!function_exists('add_action')) {
    header('Status: 403 Forbidden');
    header('HTTP/1.1 403 Forbidden');
    exit();
}

$options = $this->options;
$fonts = $this->get_font_stacks();
$sidebars = $this->get_sidebar_pos();
?>
<form id="general" method="post" action="<?php echo esc_url($tabs['general']['url']); ?>">
    <input type="hidden" name="bln-nonce-general" value="<?php echo wp_create_nonce('blueline_general'); ?>" />
    <fieldset id="typography" class="field-block">
        <legend><?php _e('Typography', 'bluelines'); ?></legend>
        <div class="option-block">
            <label><?php _e('Main font', 'bluelines'); ?></label>
            <select name="body-font" id="body-font">
            <?php foreach ($fonts as $key => $value) : ?>
                <option value="<?php echo esc_attr($key); ?>" <?php selected($options['font']['body'], $key); ?>><?php echo $key ?></option>
            <?php endforeach; ?>
            </select><!-- select[name="body-font"] -->
            <p class="desc"><?php _e('The main font used in your site.', 'bluelines'); ?></p>
        </div><!-- .option-block -->
        <div class="option-block">
            <label><?php _e('Inputs font', 'bluelines'); ?></label>
            <select name="inputs-font" id="inputs-font">
            <?php foreach ($fonts as $key => $value) : ?>
                <option value="<?php echo esc_attr($key); ?>" <?php selected($options['font']['inputs'], $key); ?>><?php echo $key ?></option>
            <?php endforeach; ?>
            </select><!-- select[name="inputs-font"] -->
            <p class="desc"><?php _e('Font used for input fields (text, password, textarea etc).', 'bluelines'); ?></p>
        </div><!-- .option-block -->
        <div class="option-block">
            <label><?php _e('Code font', 'bluelines'); ?></label>
            <select name="code-font" id="code-font">
            <?php foreach ($fonts as $key => $value) : ?>
                <option value="<?php echo esc_attr($key); ?>" <?php selected($options['font']['code'], $key); ?>><?php echo $key ?></option>
            <?php endforeach; ?>
            </select><!-- select[name="code-font"] -->
            <p class="desc"><?php _e('code and pre HTML tags.', 'bluelines'); ?></p>
        </div><!-- .option-block -->
    </fieldset>
    <div class="field-preview">
        <table class="widefat font-test">
            <thead>
                <tr>
                    <th><?php _e('Elements', 'bluelines'); ?></th>
                    <th class="alt"><?php _e('Fonts', 'bluelines'); ?></th>
                    <th><?php _e('Preview', 'bluelines'); ?></th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <td><span class="elements" id="element-body"><?php _e('Body', 'bluelines'); ?></span></td>
                    <td class="alt w-180"><strong id="option-body"><?php echo $options['font']['body'] ?></strong><p class="desc">font-family: <span id="option-body-ff"><?php echo $fonts[$options['font']['body']]; ?></span></p></td>
                    <td><span class="sample" id="sample-body">abc DEF-123 <em>xYZ</em> <strong>mNO<em>pQR</em></strong></span></td>
                </tr>
                <tr>
                    <td><span class="elements" id="element-inputs"><?php _e('Inputs', 'bluelines'); ?></span></td>
                    <td class="alt w-180"><strong id="option-inputs"><?php echo $options['font']['inputs'] ?></strong><p class="desc">font-family: <span id="option-inputs-ff"><?php echo $fonts[$options['font']['inputs']]; ?></span></p></td>
                    <td><span class="sample" id="sample-inputs">abc DEF-123 <em>xYZ</em> <strong>mNO<em>pQR</em></strong></span></td>
                </tr>
                <tr>
                    <td><span class="elements" id="element-code"><?php _e('code/pre tags', 'bluelines'); ?></span></td>
                    <td class="alt w-180"><strong id="option-code"><?php echo $options['font']['code'] ?></strong><p class="desc">font-family: <span id="option-code-ff"><?php echo $fonts[$options['font']['code']]; ?></span></p></td>
                    <td><span class="sample" id="sample-code">abc DEF-123 <em>xYZ</em> <strong>mNO<em>pQR</em></strong></span></td>
                </tr>
            </tbody>
        </table>
    </div><!-- .field-preview -->
    <fieldset>
        <legend><?php _e('Page comments', 'bluelines'); ?></legend>
        <div class="option-block">
            <label><?php _e('Comments on pages', 'bluelines'); ?></label>
            <input type="checkbox" name="page-comments" value="1" <?php checked($options['page_comments']); ?>/>
            <p class="desc"><?php _e('This option will enable comments on pages. You can disable comments for a single page in the quick edit mode of the page list screen.', 'bluelines'); ?></p>
        </div><!-- .option-block -->
    </fieldset>
    <fieldset>
        <legend><?php _e('Search form on Main nav-bar', 'bluelines'); ?></legend>
        <div class="option-block">
            <label><?php _e('Show search form', 'bluelines'); ?></label>
            <input type="checkbox" name="navbar_search" value="1" <?php checked($options['navbar_search']); ?>/>
            <p class="desc"><?php _e('This option will show the search form on the main navigation menu bar.', 'bluelines'); ?></p>
        </div><!-- .option-block -->
    </fieldset>
    <fieldset>
        <legend><?php _e('Sidebar', 'bluelines'); ?></legend>
        <div class="option-block">
            <label><?php _e('Sidebar position', 'bluelines'); ?></label>
            <select name="sidebar">
                <?php foreach ($sidebars as $key => $value) : ?>
                    <option value="<?php echo $key; ?>" <?php selected($options['sidebar'], $key); ?>><?php echo $value['desc']; ?></option>
                <?php endforeach; ?>
            </select>
            <p class="desc"><?php _e('This is the sidebar displayed on post and page default template.', 'bluelines'); ?></p>
        </div><!-- .option-block -->
    </fieldset>
    <input type="submit" class="button button-primary" name="submit" value="<?php esc_attr_e('Save Changes', 'bluelines'); ?>" />
</form><!-- #general -->
